import { Children, isValidElement, useRef, useState, useEffect, forwardRef, cloneElement, createElement, Fragment } from 'react';
import { classnames, focus, groupHover, sm, md, lg, xl } from 'tailwindcss-classnames';
import TextareaAutosize from 'react-textarea-autosize';
import { usePopper } from 'react-popper';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var DISABLED = function DISABLED(disabled) {
  return {
    'cursor-not-allowed': disabled,
    'opacity-50': disabled,
    'pointer-events-none': disabled
  };
};
var FULL_WIDTH = function FULL_WIDTH(fullWidth) {
  return {
    'w-full': fullWidth
  };
};
var removeDefault = /*#__PURE__*/classnames( /*#__PURE__*/focus('outline-none'), 'appearance-none');
var useImageLoaded = function useImageLoaded(src) {
  var isMounted = useRef(true);

  var _React$useState = useState(false),
      isLoaded = _React$useState[0],
      setIsLoaded = _React$useState[1];

  useEffect(function () {
    if (!src) return;
    var image = new Image();
    image.src = src;

    image.onload = function () {
      if (isMounted.current) {
        setIsLoaded(true);
      }
    };

    image.onerror = function () {
      if (isMounted.current) {
        setIsLoaded(false);
      }
    };
  }, [src]);
  useEffect(function () {
    return function () {
      isMounted.current = false;
    };
  }, []);
  return isLoaded;
};
var validChildren = function validChildren(children) {
  return Children.toArray(children).filter(function (child) {
    return isValidElement(child);
  });
};
var customClassHandler = function customClassHandler(customRootClass, className) {
  return ("" + (customRootClass || className || '')).trim();
};

var Accordion = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2;

  var className = props.className,
      allowMultiple = props.allowMultiple,
      allowToggle = props.allowToggle,
      children = props.children,
      classes = props.classes,
      defaultValues = props.defaultValues,
      otherProps = _objectWithoutPropertiesLoose(props, ["className", "allowMultiple", "allowToggle", "children", "values", "classes", "defaultValues"]);

  var _React$useState = useState(defaultValues),
      active = _React$useState[0],
      setActive = _React$useState[1];

  var ROOT_STYLE = {
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.width)
  };
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : _classes$root2.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();

  var expandHandler = function expandHandler(newValue) {
    var activeIncludes = active.includes(newValue);

    if (allowMultiple) {
      setActive(activeIncludes ? active.filter(function (a) {
        return a !== newValue;
      }) : active.concat([newValue]));
      return;
    }

    if (allowToggle) {
      setActive(activeIncludes ? [] : [newValue]);
      return;
    }

    setActive([newValue]);
  };

  var clonedPanels = validChildren(children).map(function (child) {
    if (isValidElement(child)) {
      return cloneElement(child, _extends({}, child.props, {
        expandHandler: expandHandler,
        activeValues: active
      }));
    } else return child;
  });
  return createElement("div", Object.assign({
    ref: ref,
    className: rootClass
  }, otherProps), clonedPanels);
});
var accordionDefaultProps = {
  allowMultiple: false,
  allowToggle: false
};
Accordion.defaultProps = accordionDefaultProps;
var AccordionItem = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$header, _classes$header$disab, _classes$header2, _classes$header2$disa, _classes$header3, _classes$header3$disa, _classes$panel, _classes$panel$disabl, _classes$root3, _classes$header4, _classes$panel2;

  var disabled = props.disabled,
      activeValues = props.activeValues,
      value = props.value,
      headerComponent = props.headerComponent,
      classes = props.classes,
      expandHandler = props.expandHandler,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["disabled", "activeValues", "value", "headerComponent", "className", "classes", "expandHandler", "children"]);

  var Header = headerComponent;

  var _React$useState2 = useState(false),
      expanded = _React$useState2[0],
      setExpanded = _React$useState2[1];

  var HEADER_STYLE = {
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$header = classes.header) === null || _classes$header === void 0 ? void 0 : (_classes$header$disab = _classes$header.disableDefault) === null || _classes$header$disab === void 0 ? void 0 : _classes$header$disab.display),
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$header2 = classes.header) === null || _classes$header2 === void 0 ? void 0 : (_classes$header2$disa = _classes$header2.disableDefault) === null || _classes$header2$disa === void 0 ? void 0 : _classes$header2$disa.width),
    'items-center': !(classes === null || classes === void 0 ? void 0 : (_classes$header3 = classes.header) === null || _classes$header3 === void 0 ? void 0 : (_classes$header3$disa = _classes$header3.disableDefault) === null || _classes$header3$disa === void 0 ? void 0 : _classes$header3$disa.alignItems)
  };
  var PANEL_STYLE = {
    'h-auto': !(classes === null || classes === void 0 ? void 0 : (_classes$panel = classes.panel) === null || _classes$panel === void 0 ? void 0 : (_classes$panel$disabl = _classes$panel.disableDefault) === null || _classes$panel$disabl === void 0 ? void 0 : _classes$panel$disabl.height)
  };
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : _classes$root3.custom;
  var rootClass = customClassHandler(customRootClass);
  var defaultHeaderClass = classnames(HEADER_STYLE, DISABLED(disabled));
  var customHeaderClass = classes === null || classes === void 0 ? void 0 : (_classes$header4 = classes.header) === null || _classes$header4 === void 0 ? void 0 : _classes$header4.custom;
  var headerClass = (defaultHeaderClass + " " + customHeaderClass).trim();
  var defaultPanelClass = classnames(PANEL_STYLE);
  var customPanelClass = classes === null || classes === void 0 ? void 0 : (_classes$panel2 = classes.panel) === null || _classes$panel2 === void 0 ? void 0 : _classes$panel2.custom;
  var panelClass = (defaultPanelClass + " " + customClassHandler(customPanelClass)).trim();
  useEffect(function () {
    if (activeValues) {
      var shouldExpand = activeValues.filter(function (activeValue) {
        return activeValue === value;
      }).length > 0;
      setExpanded(shouldExpand);
    }
  }, [activeValues, value]);
  return createElement("div", Object.assign({
    className: rootClass,
    ref: ref
  }, otherProps), expandHandler && createElement("div", {
    className: headerClass
  }, createElement(Header, {
    isExpanded: expanded,
    setExpanded: expandHandler
  })), expanded && createElement("div", {
    className: panelClass
  }, children));
});
var accordionItemDefaultProps = {
  disabled: false
};
AccordionItem.defaultProps = accordionItemDefaultProps;

var Avatar = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$avatar, _classes$avatar$disab, _classes$avatar2, _classes$avatar2$disa, _classes$avatar3, _classes$avatar3$disa, _classes$image, _classes$image$disabl, _classes$image2, _classes$image2$disab, _classes$image3, _classes$image3$disab, _classes$fallback, _classes$fallback$dis, _classes$fallback2, _classes$fallback2$di, _classes$fallback3, _classes$fallback3$di, _classes$fallback4, _classes$fallback4$di, _classes$fallback5, _classes$fallback5$di, _classes$fallback6, _classes$fallback6$di, _classes$fallback7, _classes$fallback7$di, _classes$badge, _classes$badge$disabl, _classes$badge2, _classes$badge2$disab, _classes$badge3, _classes$badge3$disab, _classes$badge4, _classes$badge4$disab, _classes$badge5, _classes$badge5$disab, _classes$badge6, _classes$badge6$disab, _classes$badge7, _classes$badge7$disab, _classes$badge8, _classes$badge8$disab, _classes$root3, _classes$avatar4, _classes$image4, _classes$fallback8, _classes$badge9;

  var variant = props.variant,
      componentSize = props.componentSize,
      classes = props.classes,
      src = props.src,
      alt = props.alt,
      withBadge = props.withBadge,
      className = props.className,
      fallback = props.fallback,
      fallbackSrc = props.fallbackSrc,
      otherProps = _objectWithoutPropertiesLoose(props, ["variant", "componentSize", "classes", "src", "alt", "withBadge", "className", "fallback", "fallbackSrc"]);

  var imageLoaded = useImageLoaded(src);
  var ROOT_STYLE = {
    relative: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.display)
  };
  var ROOT_SIZE = componentSize === 'xs' && ['w-12', 'h-12'] || componentSize === 'sm' && ['w-16', 'h-16'] || componentSize === 'md' && ['w-20', 'h-20'] || componentSize === 'lg' && ['w-32', 'h-32'] || componentSize === 'xl' && ['w-40', 'h-40'] || [];
  var AVATAR_STYLE = {
    'overflow-hidden': !(classes === null || classes === void 0 ? void 0 : (_classes$avatar = classes.avatar) === null || _classes$avatar === void 0 ? void 0 : (_classes$avatar$disab = _classes$avatar.disableDefault) === null || _classes$avatar$disab === void 0 ? void 0 : _classes$avatar$disab.overflow),
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$avatar2 = classes.avatar) === null || _classes$avatar2 === void 0 ? void 0 : (_classes$avatar2$disa = _classes$avatar2.disableDefault) === null || _classes$avatar2$disa === void 0 ? void 0 : _classes$avatar2$disa.width),
    'h-full': !(classes === null || classes === void 0 ? void 0 : (_classes$avatar3 = classes.avatar) === null || _classes$avatar3 === void 0 ? void 0 : (_classes$avatar3$disa = _classes$avatar3.disableDefault) === null || _classes$avatar3$disa === void 0 ? void 0 : _classes$avatar3$disa.height)
  };
  var BORDER_RADIUS = variant === 'circle' && 'rounded-full' || variant === 'rounded' && 'rounded-md' || variant === 'square' && 'rounded-none' || 'rounded-full';
  var IMAGE_STYLE = {
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$image = classes.image) === null || _classes$image === void 0 ? void 0 : (_classes$image$disabl = _classes$image.disableDefault) === null || _classes$image$disabl === void 0 ? void 0 : _classes$image$disabl.width),
    'h-full': !(classes === null || classes === void 0 ? void 0 : (_classes$image2 = classes.image) === null || _classes$image2 === void 0 ? void 0 : (_classes$image2$disab = _classes$image2.disableDefault) === null || _classes$image2$disab === void 0 ? void 0 : _classes$image2$disab.height),
    'object-cover': !(classes === null || classes === void 0 ? void 0 : (_classes$image3 = classes.image) === null || _classes$image3 === void 0 ? void 0 : (_classes$image3$disab = _classes$image3.disableDefault) === null || _classes$image3$disab === void 0 ? void 0 : _classes$image3$disab.objectFit)
  };
  var FALLBACK_STYLE = {
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback = classes.fallback) === null || _classes$fallback === void 0 ? void 0 : (_classes$fallback$dis = _classes$fallback.disableDefault) === null || _classes$fallback$dis === void 0 ? void 0 : _classes$fallback$dis.width),
    'h-full': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback2 = classes.fallback) === null || _classes$fallback2 === void 0 ? void 0 : (_classes$fallback2$di = _classes$fallback2.disableDefault) === null || _classes$fallback2$di === void 0 ? void 0 : _classes$fallback2$di.height),
    'bg-gray-400': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback3 = classes.fallback) === null || _classes$fallback3 === void 0 ? void 0 : (_classes$fallback3$di = _classes$fallback3.disableDefault) === null || _classes$fallback3$di === void 0 ? void 0 : _classes$fallback3$di.backgroundColor),
    'text-white': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback4 = classes.fallback) === null || _classes$fallback4 === void 0 ? void 0 : (_classes$fallback4$di = _classes$fallback4.disableDefault) === null || _classes$fallback4$di === void 0 ? void 0 : _classes$fallback4$di.color),
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback5 = classes.fallback) === null || _classes$fallback5 === void 0 ? void 0 : (_classes$fallback5$di = _classes$fallback5.disableDefault) === null || _classes$fallback5$di === void 0 ? void 0 : _classes$fallback5$di.display),
    'justify-center': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback6 = classes.fallback) === null || _classes$fallback6 === void 0 ? void 0 : (_classes$fallback6$di = _classes$fallback6.disableDefault) === null || _classes$fallback6$di === void 0 ? void 0 : _classes$fallback6$di.justifyContent),
    'items-center': !(classes === null || classes === void 0 ? void 0 : (_classes$fallback7 = classes.fallback) === null || _classes$fallback7 === void 0 ? void 0 : (_classes$fallback7$di = _classes$fallback7.disableDefault) === null || _classes$fallback7$di === void 0 ? void 0 : _classes$fallback7$di.alignItems)
  };
  var FALLBACK_FONT_SIZE = componentSize === 'xs' && 'text-xs' || componentSize === 'sm' && 'text-sm' || componentSize === 'md' && 'text-base' || componentSize === 'lg' && 'text-xl' || componentSize === 'xl' && 'text-3xl' || 'text-base';
  var BADGE_STYLE = {
    'rounded-full': !(classes === null || classes === void 0 ? void 0 : (_classes$badge = classes.badge) === null || _classes$badge === void 0 ? void 0 : (_classes$badge$disabl = _classes$badge.disableDefault) === null || _classes$badge$disabl === void 0 ? void 0 : _classes$badge$disabl.borderRadius),
    'border-gray-200': !(classes === null || classes === void 0 ? void 0 : (_classes$badge2 = classes.badge) === null || _classes$badge2 === void 0 ? void 0 : (_classes$badge2$disab = _classes$badge2.disableDefault) === null || _classes$badge2$disab === void 0 ? void 0 : _classes$badge2$disab.borderColor),
    absolute: !(classes === null || classes === void 0 ? void 0 : (_classes$badge3 = classes.badge) === null || _classes$badge3 === void 0 ? void 0 : (_classes$badge3$disab = _classes$badge3.disableDefault) === null || _classes$badge3$disab === void 0 ? void 0 : _classes$badge3$disab.position),
    'z-10': !(classes === null || classes === void 0 ? void 0 : (_classes$badge4 = classes.badge) === null || _classes$badge4 === void 0 ? void 0 : (_classes$badge4$disab = _classes$badge4.disableDefault) === null || _classes$badge4$disab === void 0 ? void 0 : _classes$badge4$disab.zIndex),
    'right-0': !(classes === null || classes === void 0 ? void 0 : (_classes$badge5 = classes.badge) === null || _classes$badge5 === void 0 ? void 0 : (_classes$badge5$disab = _classes$badge5.disableDefault) === null || _classes$badge5$disab === void 0 ? void 0 : _classes$badge5$disab.right),
    'bottom-0': !(classes === null || classes === void 0 ? void 0 : (_classes$badge6 = classes.badge) === null || _classes$badge6 === void 0 ? void 0 : (_classes$badge6$disab = _classes$badge6.disableDefault) === null || _classes$badge6$disab === void 0 ? void 0 : _classes$badge6$disab.bottom),
    'bg-gray-400': !(classes === null || classes === void 0 ? void 0 : (_classes$badge7 = classes.badge) === null || _classes$badge7 === void 0 ? void 0 : (_classes$badge7$disab = _classes$badge7.disableDefault) === null || _classes$badge7$disab === void 0 ? void 0 : _classes$badge7$disab.backgroundColor),
    'p-1': !(classes === null || classes === void 0 ? void 0 : (_classes$badge8 = classes.badge) === null || _classes$badge8 === void 0 ? void 0 : (_classes$badge8$disab = _classes$badge8.disableDefault) === null || _classes$badge8$disab === void 0 ? void 0 : _classes$badge8$disab.padding)
  };
  var BADGE_SIZE = componentSize === 'xs' && ['w-4', 'h-4', 'border-2'] || componentSize === 'sm' && ['w-5', 'h-5', 'border-2'] || componentSize === 'md' && ['w-6', 'h-6', 'border-2'] || componentSize === 'lg' && ['w-8', 'h-8', '-translate-x-1', '-translate-y-1', 'border-4'] || componentSize === 'xl' && ['w-10', 'h-10', '-translate-x-1', '-translate-y-1', 'border-4'] || [];
  var defaultRootClass = classnames.apply(void 0, [ROOT_STYLE].concat(ROOT_SIZE, [BORDER_RADIUS]));
  var customRootClass = (classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : _classes$root3.custom) || '';
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var defaultAvatarClass = classnames(AVATAR_STYLE, BORDER_RADIUS);
  var customAvatarClass = (classes === null || classes === void 0 ? void 0 : (_classes$avatar4 = classes.avatar) === null || _classes$avatar4 === void 0 ? void 0 : _classes$avatar4.custom) || '';
  var avatarClass = (defaultAvatarClass + " " + customClassHandler(customAvatarClass)).trim();
  var defaultImageClass = classnames(IMAGE_STYLE);
  var customImageClass = (classes === null || classes === void 0 ? void 0 : (_classes$image4 = classes.image) === null || _classes$image4 === void 0 ? void 0 : _classes$image4.custom) || '';
  var imageClass = (defaultImageClass + " " + customClassHandler(customImageClass)).trim();
  var defaultFallbackClass = classnames(FALLBACK_STYLE, FALLBACK_FONT_SIZE);
  var customFallbackClass = (classes === null || classes === void 0 ? void 0 : (_classes$fallback8 = classes.fallback) === null || _classes$fallback8 === void 0 ? void 0 : _classes$fallback8.custom) || '';
  var fallbackClass = (defaultFallbackClass + " " + customClassHandler(customFallbackClass)).trim();
  var defaultBadgeClass = classnames.apply(void 0, [BADGE_STYLE].concat(BADGE_SIZE));
  var customBadgeClass = (classes === null || classes === void 0 ? void 0 : (_classes$badge9 = classes.badge) === null || _classes$badge9 === void 0 ? void 0 : _classes$badge9.custom) || '';
  var badgeClass = (defaultBadgeClass + " " + customClassHandler(customBadgeClass)).trim();
  return createElement("div", Object.assign({
    ref: ref,
    className: rootClass
  }, otherProps), createElement("div", {
    className: avatarClass
  }, imageLoaded && src && createElement("img", {
    src: src,
    alt: alt,
    className: imageClass
  }) || createElement("div", {
    className: fallbackClass
  }, fallbackSrc && createElement("img", {
    src: fallbackSrc,
    alt: alt,
    className: imageClass
  }) || fallback || '')), withBadge && createElement("div", {
    className: "transform " + badgeClass
  }) || createElement(Fragment, null));
});
var defaultProps = {
  componentSize: 'md',
  variant: 'circle',
  withBadge: false
};
Avatar.defaultProps = defaultProps;

var AvatarGroup = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3;

  var componentSize = props.componentSize,
      showMax = props.showMax,
      children = props.children,
      classes = props.classes,
      className = props.className,
      otherProps = _objectWithoutPropertiesLoose(props, ["componentSize", "showMax", "children", "classes", "className"]);

  var ROOT_STYLE = {
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.display),
    'justify-center': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.justifyContent)
  };
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = (classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : _classes$root3.custom) || '';
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var validAvatars = validChildren(children);
  var avatarsCount = validAvatars.length;
  var clones = validChildren(validAvatars).map(function (child, index) {
    if (showMax && index > showMax) {
      return null;
    } else if ((!showMax || showMax && index < showMax) && isValidElement(child)) {
      var _classnames;

      var isFirstChild = index === 0;

      var ClonedAvatar = function ClonedAvatar(props) {
        return cloneElement(child, _extends({}, child.props, props));
      };

      var avatarItemClass = classnames('relative', (_classnames = {}, _classnames['-ml-6'] = !isFirstChild, _classnames));
      return createElement("div", {
        key: index,
        className: avatarItemClass,
        style: {
          zIndex: avatarsCount - index
        }
      }, createElement(ClonedAvatar, {
        componentSize: componentSize
      }));
    } else if (showMax && index === showMax) {
      return createElement(Avatar, {
        key: index,
        className: classnames('relative', '-ml-6'),
        componentSize: componentSize,
        fallback: "+" + (avatarsCount - showMax)
      });
    } else {
      return null;
    }
  });
  return createElement("div", Object.assign({
    className: rootClass,
    ref: ref
  }, otherProps), clones);
});
var defaultProps$1 = {
  showMax: 5,
  componentSize: 'md'
};
AvatarGroup.defaultProps = defaultProps$1;

var Backdrop = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4, _classes$root4$disabl, _classes$root5, _classes$root5$disabl, _classes$root6, _classes$root6$disabl, _classes$root7, _classes$root7$disabl, _classes$root8, _classes$root8$disabl, _classes$root9, _classes$root9$disabl, _classes$root10;

  var show = props.show,
      allowScroll = props.allowScroll,
      classes = props.classes,
      className = props.className,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["show", "allowScroll", "classes", "className", "children"]);

  useEffect(function () {
    var bodyElement = document.body || window.document.body;
    var bodyClass = bodyElement.classList;
    var overflowClass = classnames('overflow-hidden');

    if (show) {
      if (!allowScroll) bodyClass.add(overflowClass);
    } else {
      if (!allowScroll) bodyClass.remove(overflowClass);
    }
  }, [show, allowScroll]);
  var ROOT_STYLE = {
    fixed: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    flex: !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.display),
    'top-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.top),
    'left-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.left),
    'right-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : (_classes$root5$disabl = _classes$root5.disableDefault) === null || _classes$root5$disabl === void 0 ? void 0 : _classes$root5$disabl.right),
    'bottom-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root6 = classes.root) === null || _classes$root6 === void 0 ? void 0 : (_classes$root6$disabl = _classes$root6.disableDefault) === null || _classes$root6$disabl === void 0 ? void 0 : _classes$root6$disabl.bottom),
    'bg-black': !(classes === null || classes === void 0 ? void 0 : (_classes$root7 = classes.root) === null || _classes$root7 === void 0 ? void 0 : (_classes$root7$disabl = _classes$root7.disableDefault) === null || _classes$root7$disabl === void 0 ? void 0 : _classes$root7$disabl.backgroundColor),
    'opacity-50': !(classes === null || classes === void 0 ? void 0 : (_classes$root8 = classes.root) === null || _classes$root8 === void 0 ? void 0 : (_classes$root8$disabl = _classes$root8.disableDefault) === null || _classes$root8$disabl === void 0 ? void 0 : _classes$root8$disabl.opacity),
    'z-40': !(classes === null || classes === void 0 ? void 0 : (_classes$root9 = classes.root) === null || _classes$root9 === void 0 ? void 0 : (_classes$root9$disabl = _classes$root9.disableDefault) === null || _classes$root9$disabl === void 0 ? void 0 : _classes$root9$disabl.zIndex)
  };
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = (classes === null || classes === void 0 ? void 0 : (_classes$root10 = classes.root) === null || _classes$root10 === void 0 ? void 0 : _classes$root10.custom) || '';
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  return createElement(Fragment, null, show ? createElement("div", Object.assign({
    ref: ref,
    className: rootClass
  }, otherProps), children) : null);
});
var defaultProps$2 = {
  show: false,
  allowScroll: false
};
Backdrop.defaultProps = defaultProps$2;

var Button = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4, _classes$root4$disabl, _classes$root5, _classes$root5$disabl, _classes$root6, _classes$root6$disabl, _classes$root7;

  var children = props.children,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      className = props.className,
      _props$componentSize = props.componentSize,
      componentSize = _props$componentSize === void 0 ? 'md' : _props$componentSize,
      _props$fullWidth = props.fullWidth,
      fullWidth = _props$fullWidth === void 0 ? false : _props$fullWidth,
      _props$component = props.component,
      Component = _props$component === void 0 ? 'button' : _props$component,
      classes = props.classes,
      startIcon = props.startIcon,
      centerIcon = props.centerIcon,
      endIcon = props.endIcon,
      otherProps = _objectWithoutPropertiesLoose(props, ["children", "disabled", "className", "componentSize", "fullWidth", "component", "classes", "startIcon", "centerIcon", "endIcon"]);

  var BUTTON_ICON = startIcon || centerIcon || endIcon || null;
  var CHILDREN_WRAPPER = startIcon && createElement(Fragment, null, createElement("span", {
    className: "mr-2"
  }, BUTTON_ICON), children) || centerIcon && createElement(Fragment, null, createElement("span", {
    className: "flex flex-col"
  }, createElement("span", null, BUTTON_ICON), createElement("span", null, children))) || endIcon && createElement(Fragment, null, children, createElement("span", {
    className: "ml-2"
  }, BUTTON_ICON)) || children;
  var ROOT_STYLE = {
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.display),
    'justify-center': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.justifyContent),
    'items-center': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.alignItems),
    'box-border': !(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.boxSizing),
    'cursor-pointer': !(classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : (_classes$root5$disabl = _classes$root5.disableDefault) === null || _classes$root5$disabl === void 0 ? void 0 : _classes$root5$disabl.cursor),
    'no-underline': !(classes === null || classes === void 0 ? void 0 : (_classes$root6 = classes.root) === null || _classes$root6 === void 0 ? void 0 : (_classes$root6$disabl = _classes$root6.disableDefault) === null || _classes$root6$disabl === void 0 ? void 0 : _classes$root6$disabl.textDecoration)
  };
  var BUTTON_SIZE = componentSize === 'xs' && ['py-1', 'px-2', 'text-xs'] || componentSize === 'sm' && ['py-1', 'px-3', 'text-sm'] || componentSize === 'md' && ['py-2', 'px-4', 'text-base'] || componentSize === 'lg' && ['py-3', 'px-5', 'text-lg'] || componentSize === 'xl' && ['py-4', 'px-6', 'text-xl'] || [];
  var defaultRootClass = classnames.apply(void 0, [ROOT_STYLE].concat(BUTTON_SIZE, [DISABLED(disabled), FULL_WIDTH(fullWidth)]));
  var customRootClass = (classes === null || classes === void 0 ? void 0 : (_classes$root7 = classes.root) === null || _classes$root7 === void 0 ? void 0 : _classes$root7.custom) || '';
  var rootClass = (removeDefault + " " + defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  return Component && Component !== 'button' && createElement(Component //@ts-ignore
  , Object.assign({
    //@ts-ignore
    ref: ref,
    className: rootClass
  }, otherProps), CHILDREN_WRAPPER) || createElement("button", Object.assign({
    //@ts-ignore
    ref: ref,
    disabled: disabled,
    className: rootClass
  }, otherProps), CHILDREN_WRAPPER);
});

var Divider = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4;

  var orientation = props.orientation,
      component = props.component,
      classes = props.classes,
      className = props.className,
      otherProps = _objectWithoutPropertiesLoose(props, ["orientation", "component", "classes", "className"]);

  var ElementType = component || 'hr';
  var ROOT_STYLE = {
    'border-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.borderWidth),
    'm-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.margin),
    'bg-gray-400': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.backgroundColor)
  };
  var ORIENTATION_STYLE = orientation === 'horizontal' ? ['w-full', 'h-px'] : ['w-px', 'self-auto', 'h-auto'];
  var defaultRootClass = classnames.apply(void 0, [ROOT_STYLE].concat(ORIENTATION_STYLE));
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : _classes$root4.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  return createElement(ElementType, Object.assign({
    className: rootClass,
    ref: ref
  }, otherProps));
});
var defaultProps$3 = {
  orientation: 'horizontal',
  component: 'hr'
};
Divider.defaultProps = defaultProps$3;

var Drawer = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4, _classes$root4$disabl, _classes$root5, _classes$root5$disabl, _classes$root6, _classes$root6$disabl, _classes$drawer, _classes$drawer$disab, _classes$drawer2, _classes$drawer2$disa, _classes$drawer3, _classes$drawer3$disa, _classes$drawer4, _classes$drawer4$disa, _classes$root7, _classes$drawer5;

  var classes = props.classes,
      show = props.show,
      position = props.position,
      hideBackdrop = props.hideBackdrop,
      onBackdropClick = props.onBackdropClick,
      className = props.className,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["classes", "show", "position", "hideBackdrop", "onBackdropClick", "className", "children"]);

  var drawerRef = useRef(null);
  useEffect(function () {
    window.onclick = function (e) {
      var eventTarget = e.target;
      var modalCurrent = drawerRef.current;
      var isModalClick = eventTarget === modalCurrent || (modalCurrent === null || modalCurrent === void 0 ? void 0 : modalCurrent.contains(eventTarget));
      if (!isModalClick && onBackdropClick && show) onBackdropClick();
    };
  }, [show, onBackdropClick, drawerRef]);
  var ROOT_STYLE = {
    fixed: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    'top-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.top),
    'left-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.left),
    'right-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.right),
    'bottom-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : (_classes$root5$disabl = _classes$root5.disableDefault) === null || _classes$root5$disabl === void 0 ? void 0 : _classes$root5$disabl.bottom),
    'z-50': !(classes === null || classes === void 0 ? void 0 : (_classes$root6 = classes.root) === null || _classes$root6 === void 0 ? void 0 : (_classes$root6$disabl = _classes$root6.disableDefault) === null || _classes$root6$disabl === void 0 ? void 0 : _classes$root6$disabl.zIndex)
  };
  var DRAWER_STYLE = {
    absolute: !(classes === null || classes === void 0 ? void 0 : (_classes$drawer = classes.drawer) === null || _classes$drawer === void 0 ? void 0 : (_classes$drawer$disab = _classes$drawer.disableDefault) === null || _classes$drawer$disab === void 0 ? void 0 : _classes$drawer$disab.position),
    'bg-red-400': !(classes === null || classes === void 0 ? void 0 : (_classes$drawer2 = classes.drawer) === null || _classes$drawer2 === void 0 ? void 0 : (_classes$drawer2$disa = _classes$drawer2.disableDefault) === null || _classes$drawer2$disa === void 0 ? void 0 : _classes$drawer2$disa.backgroundColor),
    shadow: !(classes === null || classes === void 0 ? void 0 : (_classes$drawer3 = classes.drawer) === null || _classes$drawer3 === void 0 ? void 0 : (_classes$drawer3$disa = _classes$drawer3.disableDefault) === null || _classes$drawer3$disa === void 0 ? void 0 : _classes$drawer3$disa.boxShadow),
    'z-50': !(classes === null || classes === void 0 ? void 0 : (_classes$drawer4 = classes.drawer) === null || _classes$drawer4 === void 0 ? void 0 : (_classes$drawer4$disa = _classes$drawer4.disableDefault) === null || _classes$drawer4$disa === void 0 ? void 0 : _classes$drawer4$disa.zIndex)
  };
  var DRAWER_POSITION = position === 'top' && ['inset-x-0', 'top-0', 'w-full', 'h-auto'] || position === 'right' && ['inset-y-0', 'right-0', 'h-full', 'w-auto'] || position === 'left' && ['inset-y-0', 'left-0', 'h-full', 'w-auto'] || position === 'bottom' && ['inset-x-0', 'bottom-0', 'w-full', 'h-auto'] || [];
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root7 = classes.root) === null || _classes$root7 === void 0 ? void 0 : _classes$root7.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var defaultDrawerClass = classnames.apply(void 0, [DRAWER_STYLE].concat(DRAWER_POSITION));
  var customDrawerClass = classes === null || classes === void 0 ? void 0 : (_classes$drawer5 = classes.drawer) === null || _classes$drawer5 === void 0 ? void 0 : _classes$drawer5.custom;
  var drawerClass = (defaultDrawerClass + " " + customClassHandler(customDrawerClass, className)).trim();
  return createElement(Fragment, null, show && createElement("div", Object.assign({
    className: rootClass,
    ref: ref
  }, otherProps), createElement("div", {
    className: drawerClass,
    ref: drawerRef
  }, children), createElement("div", {
    className: "" + classnames({
      'opacity-0': hideBackdrop
    })
  }, createElement(Backdrop, {
    show: show
  }))));
});
var defaultProps$4 = {
  show: false,
  position: 'left',
  hideBackdrop: false
};
Drawer.defaultProps = defaultProps$4;

var Field = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4, _classes$root4$disabl, _classes$field, _classes$field$disabl, _classes$field2, _classes$field2$disab, _classes$root5, _classes$field3;

  var disabled = props.disabled,
      className = props.className,
      fullWidth = props.fullWidth,
      componentSize = props.componentSize,
      component = props.component,
      placeholder = props.placeholder,
      startElement = props.startElement,
      endElement = props.endElement,
      rowsMin = props.rowsMin,
      rowsMax = props.rowsMax,
      resize = props.resize,
      multipleSelect = props.multipleSelect,
      classes = props.classes,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["disabled", "className", "fullWidth", "componentSize", "component", "placeholder", "startElement", "endElement", "rowsMin", "rowsMax", "resize", "multipleSelect", "classes", "children"]); // const [focus, setFocus] = React.useState(false);


  var EndElement = endElement;
  var StartElement = startElement;
  var ROOT_SIZE = componentSize === 'xs' && ['py-1', 'px-2', 'text-xs'] || componentSize === 'sm' && ['py-1', 'px-3', 'text-sm'] || componentSize === 'md' && ['py-2', 'px-4', 'text-base'] || componentSize === 'lg' && ['py-3', 'px-5', 'text-lg'] || componentSize === 'xl' && ['py-4', 'px-6', 'text-xl'] || [];
  var ROOT_STYLE = {
    relative: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.display),
    'font-normal': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.fontWeight),
    'w-1/4': !!(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.width)
  }; // const CONTAINER_FOCUS = `
  //   ${focus && variant === 'outlined' ? 'border-blue-400' : ''}
  //   ${focus && variant === 'filled' ? 'bg-transparent border-blue-400' : ''}
  // `;

  var TEXTAREA_RESIZE = resize === 'none' && 'resize-none' || resize === 'horizontal' && 'resize-x' || resize === 'vertical' && 'resize-y' || resize === 'both' && 'resize' || 'resize-none';
  var FIELD_STYLE = {
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$field = classes.field) === null || _classes$field === void 0 ? void 0 : (_classes$field$disabl = _classes$field.disableDefault) === null || _classes$field$disabl === void 0 ? void 0 : _classes$field$disabl.width),
    'bg-transparent': !(classes === null || classes === void 0 ? void 0 : (_classes$field2 = classes.field) === null || _classes$field2 === void 0 ? void 0 : (_classes$field2$disab = _classes$field2.disableDefault) === null || _classes$field2$disab === void 0 ? void 0 : _classes$field2$disab.backgroundColor)
  };
  var defaultRootClass = classnames.apply(void 0, [ROOT_STYLE].concat(ROOT_SIZE, [DISABLED(disabled), FULL_WIDTH(fullWidth)]));
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : _classes$root5.cutsom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var textareaClass = classnames(TEXTAREA_RESIZE);
  var defaultFieldClass = classnames(FIELD_STYLE);
  var customFieldClass = classes === null || classes === void 0 ? void 0 : (_classes$field3 = classes.field) === null || _classes$field3 === void 0 ? void 0 : _classes$field3.custom;
  var fieldClass = (removeDefault + " " + defaultFieldClass + " " + customClassHandler(customFieldClass)).trim();
  return createElement("div", {
    ref: ref,
    className: rootClass
  }, StartElement && createElement("div", {
    className: "mr-4"
  }, createElement(StartElement, null)), component === 'input' && createElement("input", Object.assign({
    className: fieldClass,
    placeholder: placeholder
  }, otherProps)) || component === 'select' && createElement("select", Object.assign({
    className: fieldClass,
    multiple: multipleSelect || false
  }, otherProps), children) || component === 'textarea' && resize !== 'auto' && createElement("textarea", Object.assign({
    className: fieldClass + " " + textareaClass,
    placeholder: placeholder,
    rows: rowsMin
  }, otherProps)) || component === 'textarea' && resize === 'auto' && // @ts-ignore
  createElement(TextareaAutosize, Object.assign({
    className: fieldClass + " " + textareaClass,
    placeholder: placeholder,
    minRows: rowsMin,
    maxRows: rowsMax
  }, otherProps)), createElement("div", {
    className: "inline-flex justify-center items-center"
  }, EndElement && createElement(EndElement, null) || component === 'select' && !multipleSelect && createElement("svg", {
    className: "fill-current h-4 w-4",
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 20 20"
  }, createElement("path", {
    d: "M9.293 12.95l.707.707L15.657 8l-1.414-1.414L10 10.828 5.757 6.586 4.343 8z"
  })) || null));
});
var defaultProps$5 = {
  disabled: false,
  fullWidth: false,
  resize: 'none',
  multipleSelect: false,
  componentSize: 'md',
  rowsMin: 3,
  component: 'input'
};
Field.defaultProps = defaultProps$5;

var Modal = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$root3, _classes$root3$disabl, _classes$root4, _classes$root4$disabl, _classes$root5, _classes$root5$disabl, _classes$root6, _classes$root6$disabl, _classes$root7, _classes$root7$disabl, _classes$root8, _classes$root8$disabl, _classes$root9, _classes$root9$disabl, _classes$modal, _classes$modal$disabl, _classes$modal2, _classes$modal2$disab, _classes$modal3, _classes$modal3$disab, _classes$modal4, _classes$modal4$disab, _classes$modal5, _classes$modal5$disab, _classes$root10, _classes$modal6;

  var show = props.show,
      componentSize = props.componentSize,
      hideBackdrop = props.hideBackdrop,
      classes = props.classes,
      className = props.className,
      children = props.children,
      onBackdropClick = props.onBackdropClick,
      otherProps = _objectWithoutPropertiesLoose(props, ["show", "componentSize", "hideBackdrop", "classes", "className", "children", "onBackdropClick"]);

  var modalRef = useRef(null);
  useEffect(function () {
    window.onclick = function (e) {
      var eventTarget = e.target;
      var modalCurrent = modalRef.current;
      var isModalClick = eventTarget === modalCurrent || (modalCurrent === null || modalCurrent === void 0 ? void 0 : modalCurrent.contains(eventTarget)) || false;
      if (!isModalClick && onBackdropClick && show) onBackdropClick();
    };
  }, [show]);
  var ROOT_STYLE = {
    fixed: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    'top-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.top),
    'left-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : (_classes$root3$disabl = _classes$root3.disableDefault) === null || _classes$root3$disabl === void 0 ? void 0 : _classes$root3$disabl.left),
    'right-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.right),
    'bottom-0': !(classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : (_classes$root5$disabl = _classes$root5.disableDefault) === null || _classes$root5$disabl === void 0 ? void 0 : _classes$root5$disabl.bottom),
    'z-50': !(classes === null || classes === void 0 ? void 0 : (_classes$root6 = classes.root) === null || _classes$root6 === void 0 ? void 0 : (_classes$root6$disabl = _classes$root6.disableDefault) === null || _classes$root6$disabl === void 0 ? void 0 : _classes$root6$disabl.zIndex),
    flex: !(classes === null || classes === void 0 ? void 0 : (_classes$root7 = classes.root) === null || _classes$root7 === void 0 ? void 0 : (_classes$root7$disabl = _classes$root7.disableDefault) === null || _classes$root7$disabl === void 0 ? void 0 : _classes$root7$disabl.display),
    'justify-center': !(classes === null || classes === void 0 ? void 0 : (_classes$root8 = classes.root) === null || _classes$root8 === void 0 ? void 0 : (_classes$root8$disabl = _classes$root8.disableDefault) === null || _classes$root8$disabl === void 0 ? void 0 : _classes$root8$disabl.justifyContent),
    'items-center': !(classes === null || classes === void 0 ? void 0 : (_classes$root9 = classes.root) === null || _classes$root9 === void 0 ? void 0 : (_classes$root9$disabl = _classes$root9.disableDefault) === null || _classes$root9$disabl === void 0 ? void 0 : _classes$root9$disabl.alignItems)
  };
  var MODAL_STYLE = {
    'bg-white': !(classes === null || classes === void 0 ? void 0 : (_classes$modal = classes.modal) === null || _classes$modal === void 0 ? void 0 : (_classes$modal$disabl = _classes$modal.disableDefault) === null || _classes$modal$disabl === void 0 ? void 0 : _classes$modal$disabl.backgroundColor),
    shadow: !(classes === null || classes === void 0 ? void 0 : (_classes$modal2 = classes.modal) === null || _classes$modal2 === void 0 ? void 0 : (_classes$modal2$disab = _classes$modal2.disableDefault) === null || _classes$modal2$disab === void 0 ? void 0 : _classes$modal2$disab.boxShadow),
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$modal3 = classes.modal) === null || _classes$modal3 === void 0 ? void 0 : (_classes$modal3$disab = _classes$modal3.disableDefault) === null || _classes$modal3$disab === void 0 ? void 0 : _classes$modal3$disab.width),
    absolute: !(classes === null || classes === void 0 ? void 0 : (_classes$modal4 = classes.modal) === null || _classes$modal4 === void 0 ? void 0 : (_classes$modal4$disab = _classes$modal4.disableDefault) === null || _classes$modal4$disab === void 0 ? void 0 : _classes$modal4$disab.position),
    'z-50': !(classes === null || classes === void 0 ? void 0 : (_classes$modal5 = classes.modal) === null || _classes$modal5 === void 0 ? void 0 : (_classes$modal5$disab = _classes$modal5.disableDefault) === null || _classes$modal5$disab === void 0 ? void 0 : _classes$modal5$disab.zIndex)
  };
  var MODAL_SIZE = componentSize === 'xs' && ['p-2', 'max-w-full'] || componentSize === 'sm' && ['p-4', 'max-w-screen-sm'] || componentSize === 'md' && ['p-6', 'max-w-screen-md'] || componentSize === 'lg' && ['p-8', 'max-w-screen-lg'] || componentSize === 'xl' && ['p-10', 'max-w-screen-xl'] || [];
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root10 = classes.root) === null || _classes$root10 === void 0 ? void 0 : _classes$root10.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var defaultModalClass = classnames.apply(void 0, [MODAL_STYLE].concat(MODAL_SIZE));
  var customModalClass = classes === null || classes === void 0 ? void 0 : (_classes$modal6 = classes.modal) === null || _classes$modal6 === void 0 ? void 0 : _classes$modal6.custom;
  var modalClass = (defaultModalClass + " " + customClassHandler(customModalClass)).trim();
  return createElement(Fragment, null, show && createElement("div", Object.assign({
    ref: ref,
    className: rootClass
  }, otherProps), createElement("div", {
    ref: modalRef,
    className: modalClass
  }, children)), createElement("div", {
    className: "" + classnames({
      'opacity-0': hideBackdrop
    })
  }, createElement(Backdrop, {
    show: show
  })));
});
var defaultProps$6 = {
  show: false,
  componentSize: 'md',
  hideBackdrop: false
};
Modal.defaultProps = defaultProps$6;

var Popover = function Popover(props) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$label, _classes$label$disabl, _classes$label2, _classes$label2$disab, _classes$label3, _classes$label3$disab, _classes$label4, _classes$label4$disab, _classes$label5, _classes$label5$disab, _classes$label6, _classes$label6$disab, _classes$label7, _classes$label7$disab, _classes$arrow, _classes$arrow$disabl, _classes$arrow2, _classes$arrow2$disab, _classes$root3, _ref, _classes$label8, _classes$arrow3;

  var children = props.children,
      classes = props.classes,
      componentSize = props.componentSize,
      className = props.className,
      withArrow = props.withArrow,
      label = props.label,
      render = props.render,
      spacing = props.spacing,
      placement = props.placement,
      triggerEvent = props.triggerEvent,
      show = props.show,
      otherProps = _objectWithoutPropertiesLoose(props, ["children", "classes", "componentSize", "className", "withArrow", "label", "render", "spacing", "placement", "triggerEvent", "show"]);

  var _React$useState = useState(show || false),
      showPopover = _React$useState[0],
      setShowPopover = _React$useState[1];

  var _React$useState2 = useState(null),
      referenceElement = _React$useState2[0],
      setReferenceElement = _React$useState2[1];

  var _React$useState3 = useState(null),
      popperElement = _React$useState3[0],
      setPopperElement = _React$useState3[1];

  var _React$useState4 = useState(null),
      arrowElement = _React$useState4[0],
      setArrowElement = _React$useState4[1];

  var Content = render;
  var ADDITIONAL_POPOVER_SPACING = (componentSize === 'lg' || componentSize === 'xl') && 10 || 6; // @ts-ignore

  var _usePopper = usePopper(referenceElement, popperElement, {
    placement: placement,
    modifiers: [{
      name: 'arrow',
      options: {
        element: arrowElement
      }
    }, {
      name: 'offset',
      options: {
        offset: [0, withArrow && spacing ? spacing + ADDITIONAL_POPOVER_SPACING : spacing]
      }
    }]
  }),
      styles = _usePopper.styles,
      attributes = _usePopper.attributes;

  var ROOT_STYLE = {
    relative: !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.position),
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.display)
  };
  var LABEL_STYLE = {
    'w-auto': !(classes === null || classes === void 0 ? void 0 : (_classes$label = classes.label) === null || _classes$label === void 0 ? void 0 : (_classes$label$disabl = _classes$label.disableDefault) === null || _classes$label$disabl === void 0 ? void 0 : _classes$label$disabl.width),
    'bg-black': !(classes === null || classes === void 0 ? void 0 : (_classes$label2 = classes.label) === null || _classes$label2 === void 0 ? void 0 : (_classes$label2$disab = _classes$label2.disableDefault) === null || _classes$label2$disab === void 0 ? void 0 : _classes$label2$disab.backgroundColor),
    'text-white': !(classes === null || classes === void 0 ? void 0 : (_classes$label3 = classes.label) === null || _classes$label3 === void 0 ? void 0 : (_classes$label3$disab = _classes$label3.disableDefault) === null || _classes$label3$disab === void 0 ? void 0 : _classes$label3$disab.color),
    'text-center': !(classes === null || classes === void 0 ? void 0 : (_classes$label4 = classes.label) === null || _classes$label4 === void 0 ? void 0 : (_classes$label4$disab = _classes$label4.disableDefault) === null || _classes$label4$disab === void 0 ? void 0 : _classes$label4$disab.textAlign),
    absolute: !(classes === null || classes === void 0 ? void 0 : (_classes$label5 = classes.label) === null || _classes$label5 === void 0 ? void 0 : (_classes$label5$disab = _classes$label5.disableDefault) === null || _classes$label5$disab === void 0 ? void 0 : _classes$label5$disab.position),
    'z-10': !(classes === null || classes === void 0 ? void 0 : (_classes$label6 = classes.label) === null || _classes$label6 === void 0 ? void 0 : (_classes$label6$disab = _classes$label6.disableDefault) === null || _classes$label6$disab === void 0 ? void 0 : _classes$label6$disab.zIndex),
    'whitespace-no-wrap': !(classes === null || classes === void 0 ? void 0 : (_classes$label7 = classes.label) === null || _classes$label7 === void 0 ? void 0 : (_classes$label7$disab = _classes$label7.disableDefault) === null || _classes$label7$disab === void 0 ? void 0 : _classes$label7$disab.whiteSpace)
  };
  var LABEL_SIZE = componentSize === 'xs' && ['p-1', 'text-xs'] || componentSize === 'sm' && ['p-2', 'text-sm'] || componentSize === 'md' && ['p-2', 'text-base'] || componentSize === 'lg' && ['p-3', 'text-lg'] || componentSize === 'xl' && ['p-4', 'text-xl'] || [];
  var ARROW_STYLE = {
    'fill-current': !(classes === null || classes === void 0 ? void 0 : (_classes$arrow = classes.arrow) === null || _classes$arrow === void 0 ? void 0 : (_classes$arrow$disabl = _classes$arrow.disableDefault) === null || _classes$arrow$disabl === void 0 ? void 0 : _classes$arrow$disabl.fill),
    'text-black': !(classes === null || classes === void 0 ? void 0 : (_classes$arrow2 = classes.arrow) === null || _classes$arrow2 === void 0 ? void 0 : (_classes$arrow2$disab = _classes$arrow2.disableDefault) === null || _classes$arrow2$disab === void 0 ? void 0 : _classes$arrow2$disab.color)
  };
  var ARROW_ROTATION = placement === 'top' && 'rotate-90' || placement === 'left' && 'rotate-0' || placement === 'bottom' && '-rotate-90' || placement === 'right' && 'rotate-180' || 'rotate-0';
  var ARROW_SIZE = componentSize === 'xs' && ['w-1', 'h-1'] || componentSize === 'sm' && ['w-2', 'h-2'] || componentSize === 'md' && ['w-3', 'h-3'] || componentSize === 'lg' && ['w-4', 'h-4'] || componentSize === 'xl' && ['w-5', 'h-5'] || [];
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : _classes$root3.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var defaultLabelClass = classnames.apply(void 0, [LABEL_STYLE].concat(LABEL_SIZE, [groupHover('visible'), (_ref = {}, _ref['invisible'] = !showPopover, _ref)]));
  var customLableClass = classes === null || classes === void 0 ? void 0 : (_classes$label8 = classes.label) === null || _classes$label8 === void 0 ? void 0 : _classes$label8.custom;
  var labelClass = (defaultLabelClass + " " + customClassHandler(customLableClass)).trim();
  var defaultArrowClass = classnames.apply(void 0, [ARROW_STYLE, ARROW_ROTATION].concat(ARROW_SIZE));
  var customArrowClass = classes === null || classes === void 0 ? void 0 : (_classes$arrow3 = classes.arrow) === null || _classes$arrow3 === void 0 ? void 0 : _classes$arrow3.custom;
  var arrowClass = (defaultArrowClass + " " + customClassHandler(customArrowClass)).trim();

  var showPopoverHandler = function showPopoverHandler(internalEvent) {
    if (triggerEvent === 'none') return;

    if (triggerEvent === 'hover') {
      if (internalEvent === 'onMouseOver') {
        setShowPopover(true);
      } else if (internalEvent === 'onMouseOut') {
        setShowPopover(false);
      }
    }

    if (triggerEvent === 'focus') {
      if (internalEvent === 'onFocus') {
        setShowPopover(true);
      } else if (internalEvent === 'onBlur') {
        setShowPopover(false);
      }
    }

    if (triggerEvent === 'click' && internalEvent === 'onClick') {
      if (showPopover === true) {
        return setShowPopover(false);
      } else {
        return setShowPopover(true);
      }
    }
  };

  var arrowPlacementHandler = function arrowPlacementHandler() {
    var componentSizeRange = (componentSize === 'xs' || componentSize === 'sm' || componentSize === 'md') && '-9px' || '-13px';
    var finalPlacement = {
      bottom: componentSizeRange
    };

    if (componentSize && placement) {
      switch (placement) {
        case 'top':
          finalPlacement = {
            bottom: componentSizeRange
          };
          break;

        case 'right':
          finalPlacement = {
            left: componentSizeRange
          };
          break;

        case 'bottom':
          finalPlacement = {
            top: componentSizeRange
          };
          break;

        case 'left':
          finalPlacement = {
            right: componentSizeRange
          };
          break;

        default:
          finalPlacement = {
            top: componentSizeRange
          };
          break;
      }
    }

    return finalPlacement;
  };

  return createElement(Fragment, null, createElement("div", Object.assign({
    className: rootClass,
    // @ts-ignore
    ref: setReferenceElement,
    onClick: function onClick() {
      return showPopoverHandler('onClick');
    },
    onMouseOver: function onMouseOver() {
      return showPopoverHandler('onMouseOver');
    },
    onMouseOut: function onMouseOut() {
      return showPopoverHandler('onMouseOut');
    },
    onFocus: function onFocus() {
      return showPopoverHandler('onFocus');
    },
    onBlur: function onBlur() {
      return showPopoverHandler('onBlur');
    }
  }, otherProps), children), createElement("div", Object.assign({
    // @ts-ignore
    ref: setPopperElement,
    style: styles.popper,
    className: labelClass
  }, attributes.popper), label || (Content ? createElement(Content, {
    show: showPopover,
    setShow: setShowPopover
  }) : null), withArrow && createElement("div", {
    // @ts-ignore
    ref: setArrowElement,
    style: _extends({}, styles.arrow, arrowPlacementHandler()),
    "data-popper-arrow": true
  }, createElement("svg", {
    className: "transform " + arrowClass,
    version: "1.1",
    xmlns: "http://www.w3.org/2000/svg",
    x: "0px",
    y: "0px",
    viewBox: "0 0 41.999 41.999"
  }, createElement("path", {
    d: "M36.068,20.176l-29-20C6.761-0.035,6.363-0.057,6.035,0.114C5.706,0.287,5.5,0.627,5.5,0.999v40 c0,0.372,0.206,0.713,0.535,0.886c0.146,0.076,0.306,0.114,0.465,0.114c0.199,0,0.397-0.06,0.568-0.177l29-20 c0.271-0.187,0.432-0.494,0.432-0.823S36.338,20.363,36.068,20.176z"
  }))) || createElement(Fragment, null)));
};
var defaultProps$7 = {
  withArrow: false,
  placement: 'bottom',
  componentSize: 'md',
  spacing: 5,
  triggerEvent: 'hover',
  show: false
};
Popover.defaultProps = defaultProps$7;

var Tabs = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root, _classes$root$disable, _classes$root2, _classes$root2$disabl, _classes$list, _classes$list$disable, _classes$list2, _classes$list2$disabl, _classes$list3, _classes$list3$disabl, _classes$root3, _classes$list4, _classes$list5, _classes$list5$disabl;

  var onTabChange = props.onTabChange,
      className = props.className,
      classes = props.classes,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["value", "onTabChange", "className", "classes", "children"]);

  var ROOT_STYLE = {
    'inline-flex': !(classes === null || classes === void 0 ? void 0 : (_classes$root = classes.root) === null || _classes$root === void 0 ? void 0 : (_classes$root$disable = _classes$root.disableDefault) === null || _classes$root$disable === void 0 ? void 0 : _classes$root$disable.display),
    'flex-wrap': !(classes === null || classes === void 0 ? void 0 : (_classes$root2 = classes.root) === null || _classes$root2 === void 0 ? void 0 : (_classes$root2$disabl = _classes$root2.disableDefault) === null || _classes$root2$disabl === void 0 ? void 0 : _classes$root2$disabl.flexWrap)
  };
  var LIST_STYLE = {
    flex: !(classes === null || classes === void 0 ? void 0 : (_classes$list = classes.list) === null || _classes$list === void 0 ? void 0 : (_classes$list$disable = _classes$list.disableDefault) === null || _classes$list$disable === void 0 ? void 0 : _classes$list$disable.display),
    'flex-wrap': !(classes === null || classes === void 0 ? void 0 : (_classes$list2 = classes.list) === null || _classes$list2 === void 0 ? void 0 : (_classes$list2$disabl = _classes$list2.disableDefault) === null || _classes$list2$disabl === void 0 ? void 0 : _classes$list2$disabl.flexWrap),
    'flex-row': !(classes === null || classes === void 0 ? void 0 : (_classes$list3 = classes.list) === null || _classes$list3 === void 0 ? void 0 : (_classes$list3$disabl = _classes$list3.disableDefault) === null || _classes$list3$disabl === void 0 ? void 0 : _classes$list3$disabl.flexDirection)
  };
  var defaultRootClass = classnames(ROOT_STYLE);
  var customRootClass = classes === null || classes === void 0 ? void 0 : (_classes$root3 = classes.root) === null || _classes$root3 === void 0 ? void 0 : _classes$root3.custom;
  var rootClass = (defaultRootClass + " " + customClassHandler(customRootClass, className)).trim();
  var defaultListClass = classnames(LIST_STYLE);
  var customListClass = classes === null || classes === void 0 ? void 0 : (_classes$list4 = classes.list) === null || _classes$list4 === void 0 ? void 0 : _classes$list4.custom;
  var listClass = (defaultListClass + " " + customClassHandler(customListClass)).trim();
  var clonedTabs = validChildren(children).map(function (child) {
    if (isValidElement(child)) {
      return cloneElement(child, _extends({}, child.props, {
        setTab: onTabChange
      }));
    } else return child;
  });
  return createElement("div", Object.assign({
    className: rootClass,
    ref: ref
  }, otherProps), createElement("ul", {
    className: listClass + " " + (!(classes === null || classes === void 0 ? void 0 : (_classes$list5 = classes.list) === null || _classes$list5 === void 0 ? void 0 : (_classes$list5$disabl = _classes$list5.disableDefault) === null || _classes$list5$disabl === void 0 ? void 0 : _classes$list5$disabl.listStyleType) ? 'list-none' : '')
  }, clonedTabs));
});
var Tab = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$root4, _classes$root4$disabl, _classes$root5;

  var value = props.value,
      classes = props.classes,
      disabled = props.disabled,
      className = props.className,
      children = props.children,
      setTab = props.setTab,
      otherProps = _objectWithoutPropertiesLoose(props, ["value", "classes", "disabled", "className", "children", "setTab"]);

  var ROOT_STYLES = {
    'flex-auto': !(classes === null || classes === void 0 ? void 0 : (_classes$root4 = classes.root) === null || _classes$root4 === void 0 ? void 0 : (_classes$root4$disabl = _classes$root4.disableDefault) === null || _classes$root4$disabl === void 0 ? void 0 : _classes$root4$disabl.flex)
  };
  var rootClass = classnames(ROOT_STYLES, DISABLED(disabled));
  var customRootClass = (classes === null || classes === void 0 ? void 0 : (_classes$root5 = classes.root) === null || _classes$root5 === void 0 ? void 0 : _classes$root5.custom) || '';
  return createElement("li", Object.assign({
    className: rootClass + " " + customRootClass + " " + (className || ''),
    ref: ref,
    onClick: function onClick() {
      return setTab ? setTab(value) : null;
    }
  }, otherProps), children);
});
var tabDefaultProps = {
  disabled: false
};
Tab.defaultProps = tabDefaultProps;
var TabPanel = /*#__PURE__*/forwardRef(function (props, ref) {
  var value = props.value,
      activeTab = props.activeTab,
      children = props.children,
      otherProps = _objectWithoutPropertiesLoose(props, ["value", "activeTab", "children"]);

  return value === activeTab ? createElement("div", Object.assign({
    ref: ref
  }, otherProps), children) : null;
});

var Grid = /*#__PURE__*/forwardRef(function (props, ref) {
  var _classes$container, _classes$container$di, _classes$container2, _classes$container2$d, _classes$container3, _classes$container3$d, _classes$container4, _classes$container4$d, _classes$container5, _classes$container5$d, _classes$container6, _classes$container6$d, _classes$container7, _classes$item;

  var xs = props.xs,
      sm$1 = props.sm,
      md$1 = props.md,
      lg$1 = props.lg,
      xl$1 = props.xl,
      item = props.item,
      spacing = props.spacing,
      classes = props.classes,
      className = props.className,
      children = props.children,
      style = props.style,
      otherProps = _objectWithoutPropertiesLoose(props, ["xs", "sm", "md", "lg", "xl", "item", "spacing", "classes", "className", "children", "style"]);

  var CONTAINER_STYLE = {
    flex: !(classes === null || classes === void 0 ? void 0 : (_classes$container = classes.container) === null || _classes$container === void 0 ? void 0 : (_classes$container$di = _classes$container.disableDefault) === null || _classes$container$di === void 0 ? void 0 : _classes$container$di.display),
    'w-full': !(classes === null || classes === void 0 ? void 0 : (_classes$container2 = classes.container) === null || _classes$container2 === void 0 ? void 0 : (_classes$container2$d = _classes$container2.disableDefault) === null || _classes$container2$d === void 0 ? void 0 : _classes$container2$d.width),
    'justify-start': !(classes === null || classes === void 0 ? void 0 : (_classes$container3 = classes.container) === null || _classes$container3 === void 0 ? void 0 : (_classes$container3$d = _classes$container3.disableDefault) === null || _classes$container3$d === void 0 ? void 0 : _classes$container3$d.justifyContent),
    'items-center': !(classes === null || classes === void 0 ? void 0 : (_classes$container4 = classes.container) === null || _classes$container4 === void 0 ? void 0 : (_classes$container4$d = _classes$container4.disableDefault) === null || _classes$container4$d === void 0 ? void 0 : _classes$container4$d.alignItems),
    'flex-wrap': !(classes === null || classes === void 0 ? void 0 : (_classes$container5 = classes.container) === null || _classes$container5 === void 0 ? void 0 : (_classes$container5$d = _classes$container5.disableDefault) === null || _classes$container5$d === void 0 ? void 0 : _classes$container5$d.flexWrap),
    'flex-row': !(classes === null || classes === void 0 ? void 0 : (_classes$container6 = classes.container) === null || _classes$container6 === void 0 ? void 0 : (_classes$container6$d = _classes$container6.disableDefault) === null || _classes$container6$d === void 0 ? void 0 : _classes$container6$d.flexDirection)
  };
  var ITEM_MEDIA = [xs || 'w-auto', sm(sm$1 || 'w-auto'), md(md$1 || 'w-auto'), lg(lg$1 || 'w-auto'), xl(xl$1 || 'w-auto')];
  var containerClass = classnames(CONTAINER_STYLE);
  var customContainerClass = (classes === null || classes === void 0 ? void 0 : (_classes$container7 = classes.container) === null || _classes$container7 === void 0 ? void 0 : _classes$container7.custom) || '';
  var itemClass = classnames.apply(void 0, ITEM_MEDIA);
  var customItemClass = (classes === null || classes === void 0 ? void 0 : (_classes$item = classes.item) === null || _classes$item === void 0 ? void 0 : _classes$item.custom) || '';
  var applyClass = item ? itemClass + " " + customItemClass : containerClass + " " + customContainerClass;
  var containerSpacing = spacing ? {
    margin: "-" + spacing + "px"
  } : {};

  var ClonedItems = function ClonedItems() {
    return createElement(Fragment, null, validChildren(children).map(function (child, index) {
      if (!isValidElement(child)) return null;

      var ClonedItem = function ClonedItem(props) {
        return cloneElement(child, _extends({}, child.props, props));
      };

      var itemSpacing = spacing ? {
        padding: spacing + "px"
      } : {};
      return createElement(ClonedItem, {
        key: index,
        style: _extends({}, itemSpacing)
      });
    }));
  };

  return createElement("div", Object.assign({
    ref: ref,
    className: applyClass + " " + (className || ''),
    style: _extends({}, style, containerSpacing)
  }, otherProps), !item ? createElement(ClonedItems, null) : children);
});
var defaultProps$8 = {
  item: false,
  spacing: 0,
  xs: 'w-auto',
  sm: 'w-auto',
  md: 'w-auto',
  lg: 'w-auto',
  xl: 'w-auto'
};
Grid.defaultProps = defaultProps$8;

export { Accordion, AccordionItem, Avatar, AvatarGroup, Backdrop, Button, Divider, Drawer, Field, Grid, Modal, Popover, Tab, TabPanel, Tabs };
//# sourceMappingURL=react-tailwindcss-components.esm.js.map
